###################
Spectra Synthesizer
###################

This library provides a set of tools for the analysis of astronomical spectra. The chemical model includes a sampler of
the direct method parameter space. Moreover, this sampler can be used to fit photoionization model grids. Finally, the
library includes tools for the analysis of the stellar and gas continua.

This package is currently in an alpha estate. The preliminary documentation can be found at `readthedocs <https://specsy.readthedocs.io/>`_.

Installation
============

The library can be installed directly from its pip_ project page running the command:

``pip install specsy``

Development
===========

SpecSy is currently in an alpha release. Please check its github_ for the latest version.

.. _pip: https://pypi.org/project/specsy/
.. _github: https://github.com/Vital-Fernandez/specy

